# exploratory
Exploratory Data Analysis

## Description

This project explortory was created to perform Exploratory Data Analysis on any structured dataset. Dataset can have categorical or numerical data types. 
This project takes pandas dataframe and gives summary statistics and individual plots having categorical count for catagorical variables and PDF's, CDF's with mean, median and mode for numerical variables. The both the results are stored in PDF and CSV file in your current directory/path.  


## Installation:
Use the package manager [pip](https://pypi.org/project/exploratory/) to install exploratory
```bash
pip install exploratory
```
## Usage:

```python
from exploratory import EDA
EDA(df)
# df --> pandas dataframe
#Please input the DPI value, as DPI value increases runtime would increase. Defualt DPI value: 150
```
## Contributing
Pull requests are welcome. Please use this 'https://github.com/Abhilash-MS/exploratory' 
Please feel free to contact authors for any suggestions or issues,  Ram <kakarlaramcharan@gmail.com>, Abhilash <abhilashmaspalli1996@gmail.com> 
